@@ -42,9 +42,11 @@ class TorchFitter:
                  verbose=0,
                  validation_scheduler=True,
                  step_scheduler=False):
+
         if type(loss) == type:
-            loss = loss()
-        self.loss_function = loss
+            self.loss_function = loss()
+        else:
+            self.loss_function = loss
 
         self.epoch = 0  # current epoch
         self.n_epochs = n_epochs
@@ -131,8 +133,8 @@ class TorchFitter:
         self.model.eval()
         summary_loss = AverageMeter()
         t = time.time()
-        for step, (images, targets) in enumerate(val_loader):
-            if self.verbose:
+        for step, (images, labels) in enumerate(val_loader):
+            if self.verbose > 0:
                 if step % self.verbose == 0:
                     print(
                         f'Val Step {step}/{len(val_loader)}, '
@@ -140,14 +142,13 @@ class TorchFitter:
                         f'time: {(time.time() - t):.5f}', end='\r'
                     )
             with torch.no_grad():  # no gradient update
-                images = torch.stack(images)
                 batch_size = images.shape[0]
                 images = images.to(self.device).float()
-                boxes = [target['boxes'].to(self.device).float() for target in targets]
-                labels = [target['labels'].to(self.device).float() for target in targets]
+                labels = labels.to(self.device).float()
 
                 # just forward propagation
-                loss, _, _ = self.model(images, boxes, labels)
+                output = self.model(images)
+                loss = self.loss_function(output, labels)
                 summary_loss.update(loss.detach().item(), batch_size)
 
         return summary_loss
@@ -173,9 +174,9 @@ class TorchFitter:
                         f'time: {(time.time() - t):.5f}', end='\r'
                     )
             # extract images and labels from the dataloader
-            images = images.to(self.device).float()
             batch_size = images.shape[0]
-            labels.to(self.device).float()
+            images = images.to(self.device).float()
+            labels = labels.to(self.device).float()
 
             self.optimizer.zero_grad()
 
